<?php

/**
 * @file
 * Post-update functions for the lightbox_tobii module.
 */

use Symfony\Component\Yaml\Yaml;

/**
 * Move the zoom_text configuration setting to the tobii_settings YAML field.
 */
function lightbox_tobii_post_update_move_zoomtext_to_yaml() {
  $config_factory = \Drupal::configFactory();
  $config = $config_factory->getEditable('lightbox_tobii.settings');

  // Get the deprecated zoom_text value.
  $zoom_text = $config->get('zoom_text');

  if ($zoom_text !== NULL) {
    // Get the existing YAML configuration from the new setting, if any.
    $yaml_string = $config->get('tobii_settings') ?: '';

    // Decode YAML safely into an array.
    $yaml_data = Yaml::parse($yaml_string) ?? [];

    // Move the zoom text value to the new YAML structure.
    $yaml_data['zoomText'] = $zoom_text;

    // Encode the modified structure back to YAML.
    $new_yaml_string = Yaml::dump($yaml_data, 2);

    // Save the new value.
    $config
      ->set('tobii_settings', $new_yaml_string)
      ->clear('zoom_text')
      ->save();
  }

  return t('Moved zoom_text setting to the new tobii_settings setting (YAML).');
}
